@@ -6,6 +6,7 @@ use strict;
 use base 'Test::Count::Base';
 
 use Test::Count;
+use Test::Count::Lib;
 
 =head1 NAME
 
@@ -13,7 +14,7 @@ Test::Count::FileMutator - modify a file in place
 
 =cut
 
-our $VERSION = '0.0702';
+our $VERSION = '0.0800';
 
 sub _counter
 {
@@ -86,7 +87,7 @@ sub _init
     my $self = shift;
     my $args = shift;
 
-    $args->{plan_prefix_regex} ||= qr{(?:(?:use Test.*\btests)|plan tests)\s*=>\s*};
+    $args->{plan_prefix_regex} ||= Test::Count::Lib::perl_plan_prefix_regex();
 
     # Remmed out because Test::Count handles it by itself.
     # if (defined($args->{assert_prefix_regex}))
