@@ -7,13 +7,15 @@ use base 'Test::Count::Base';
 
 use Test::Count;
 
+use Test::Count::Lib;
+
 =head1 NAME
 
 Test::Count::Filter - a filter that counts the tests and updates the test count.
 
 =cut
 
-our $VERSION = '0.0702';
+our $VERSION = '0.0800';
 
 sub _counter
 {
@@ -92,7 +94,7 @@ sub _init
 
     $args->{input_fh} ||= \*STDIN;
     $args->{output_fh} ||= \*STDOUT;
-    $args->{plan_prefix_regex} ||= qr{(?:(?:use Test.*\btests)|plan tests)\s*=>\s*};
+    $args->{plan_prefix_regex} ||= Test::Count::Lib::perl_plan_prefix_regex();
 
 
     # Remmed out because Test::Count handles it by itself.
